@@ -4,7 +4,7 @@ from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.orm import sessionmaker
 from sqlalchemy.sql.expression import false, true
 
-from sqlalchemy_defaults import Column, LazyConfigured, lazy_config_listener
+from sqlalchemy_defaults import Column, make_lazy_configured
 
 
 class TestCase(object):
@@ -14,7 +14,7 @@ class TestCase(object):
         )
         self.Model = declarative_base()
 
-        self.User = self.create_user_model(**self.column_options)
+        self.create_models(**self.column_options)
         sa.orm.configure_mappers()
         self.columns = self.User.__table__.c
         self.Model.metadata.create_all(self.engine)
@@ -27,9 +27,10 @@ class TestCase(object):
         self.Model.metadata.drop_all(self.engine)
         self.engine.dispose()
 
-    def create_user_model(self, **options):
-        class User(self.Model, LazyConfigured):
+    def create_models(self, **options):
+        class User(self.Model):
             __tablename__ = 'user'
+            __lazy_options__ = options
 
             id = Column(Integer, primary_key=True)
             name = Column(Unicode(255))
@@ -40,15 +41,19 @@ class TestCase(object):
             created_at = Column(sa.DateTime, info={'auto_now': True})
             description = Column(sa.UnicodeText)
 
+        class Article(self.Model):
+            __tablename__ = 'article'
             __lazy_options__ = options
+            id = Column(Integer, primary_key=True)
+            name = Column(Unicode(255))
+            author_id = Column(Integer, sa.ForeignKey(User.id))
 
-        return User
+        self.User = User
+        self.Article = Article
 
 
-sa.event.listen(
-    sa.orm.mapper,
-    'mapper_configured',
-    lazy_config_listener
+make_lazy_configured(
+    sa.orm.mapper
 )
 
 
@@ -94,6 +99,9 @@ class TestLazyConfigurableDefaults(TestCase):
             sa.func.now().__class__
         )
 
+    def test_assigns_indexes_for_foreign_keys(self):
+        assert self.Article.__table__.c.author_id.index is True
+
 
 class TestLazyConfigurableOptionOverriding(TestCase):
     column_options = {
